@@ -13,15 +13,15 @@ use warnings;
 
 package Games::Risk::GUI::Board;
 BEGIN {
-  $Games::Risk::GUI::Board::VERSION = '3.101430';
+  $Games::Risk::GUI::Board::VERSION = '3.101510';
 }
 # ABSTRACT: board gui component
 
+use POE            qw{ Loop::Tk };
 use Image::Magick;
 use Image::Size;
 use List::Util     qw{ min };
 use MIME::Base64;
-use POE            qw{ Loop::Tk };
 use Readonly;
 use Tk;
 use Tk::Balloon;
@@ -29,11 +29,11 @@ use Tk::JPEG;
 use Tk::PNG;
 use Tk::Sugar;
 
-use Games::Risk::GUI::Cards;
 use Games::Risk::GUI::GameOver;
 use Games::Risk::GUI::MoveArmies;
 use Games::Risk::I18N      qw{ T };
 use Games::Risk::Resources qw{ image $SHAREDIR };
+use Games::Risk::Tk::Cards;
 use Games::Risk::Tk::Continents;
 
 
@@ -41,6 +41,7 @@ use constant K => $poe_kernel;
 
 Readonly my $WAIT_CLEAN_AI    => 1.000;
 Readonly my $WAIT_CLEAN_HUMAN => 0.250;
+Readonly my $FLASHDELAY       => 0.150;
 
 
 #--
@@ -91,6 +92,7 @@ sub spawn {
             attack_move                    => \&_onpub_attack_move,
             chnum                          => \&_onpub_country_redraw,
             chown                          => \&_onpub_country_redraw,
+            flash_country                  => \&_onpub_flash_country,
             game_over                      => \&_onpub_game_over,
             load_map                       => \&_onpub_load_map,
             move_armies                    => \&_onpub_move_armies,
@@ -276,6 +278,64 @@ sub _onpub_country_redraw {
 }
 
 
+#
+# event: flash_country( $country )
+#
+# request $country to be flashed on the map. this is done by
+# extracting the country from the greyscale image, and paint it in
+# white on the canvas.
+#
+# event: flash_country( $country , [ $state, $left ] )
+#
+# once the image is created, the event yields itself back after
+# $FLASHDELAY, and shows/hides the image depending on $state. when $left hits 0 (decremented each state change), the image is discarded.
+#
+sub _onpub_flash_country {
+    my ($h, $country, $on, $left) = @_[HEAP, ARG0 .. $#_];
+    my $c = $h->{canvas};
+
+    # first time that the country is flashed
+    if ( not defined $on ) {
+        # load greyscale image...
+        my $magick = Image::Magick->new;
+        $magick->Read( Games::Risk->new->map->greyscale );
+
+        # and paint everything that isn't the country in white
+        my $id = $country->id;
+        my $grey = "rgb($id,$id,$id)";
+        $magick->FloodfillPaint(fuzz=>0, fill=>'white', bordercolor=>$grey, invert=>1);
+        $magick->Negate;                        # turn white in black
+        $magick->Transparent( color=>'black' ); # mark black as transparent
+
+        # resize the image to fit canvas zoom
+        my ($zoomx, $zoomy) = @{ $h->{zoom} };
+        my $width  = $magick->Get('width');
+        my $height = $magick->Get('height');
+        $magick->Scale(width=>$width * $zoomx, height=>$height * $zoomy);
+
+        # remove all the uninteresting bits around the country itself
+        $magick->Trim;
+        my $coordx = $magick->Get('page.x');
+        my $coordy = $magick->Get('page.y');
+        $magick->Set(page=>'0x0+0+0');          # reset the page (resize image to trimmed zone)
+
+        # create the image and display it on the canvas
+        my $img = $c->Photo( -data => encode_base64( $magick->ImageToBlob ) );
+        $c->createImage($coordx, $coordy, -anchor=>'nw', -image=>$img, -tags=>["flash$country"]);
+
+        $on   = 1;
+        $left = 8;
+    }
+    my $method = $on ? 'raise' : 'lower';
+    $c->$method("flash$country", 'background' );
+    if ( $left ) {
+        K->delay( flash_country => $FLASHDELAY => $country, !$on, $left-1 );
+    } else {
+        $c->delete( "flash$country" );
+    }
+}
+
+
 #
 # event: game_over( $player );
 #
@@ -761,7 +821,7 @@ sub _onpriv_start {
     $top->protocol( WM_DELETE_WINDOW => $s->postback('_window_close') );
 
     #-- other window
-    Games::Risk::GUI::Cards->spawn({parent=>$top});
+    Games::Risk::Tk::Cards->new({parent=>$top});
     Games::Risk::Tk::Continents->new({parent=>$top});
     Games::Risk::GUI::MoveArmies->spawn({parent=>$top});
 
@@ -1317,7 +1377,7 @@ Games::Risk::GUI::Board - board gui component
 
 =head1 VERSION
 
-version 3.101430
+version 3.101510
 
 =head1 SYNOPSIS
 
